@@ -103,7 +103,7 @@ void ManageCiscoCert::deleteCertClicked()
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry ( i18n ( "Process (%1) started." ).arg ("cisco_cert_mgr" ),GlobalConfig->debug );
 
-				TQCString password;
+				TQString password;
 				int result = KPasswordDialog::getPassword(password, i18n("Certificate password"));
 
 				if (result == KPasswordDialog::Accepted)
@@ -112,7 +112,7 @@ void ManageCiscoCert::deleteCertClicked()
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry ( i18n ( "Certicate password got from user, send it..." ),GlobalConfig->debug );
 
-					DeleteProcess->writeToStdin( TQString(password)+"\n");
+					DeleteProcess->writeToStdin( password+"\n");
 				while (DeleteProcess->isRunning())
 				{
 					sleep(1);
