@@ -243,7 +243,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 					// 				GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "got %1 message" ).arg("'password'"), GlobalConfig->debug );
 					//
 					// 			TQString req = line.section( TQRegExp( ".*'(.*)'.*" ), 0, 0 ); // $1;
-					// 			TQCString password;
+					// 			TQString password;
 					// 			TQString pass = "";
 					// 			int result = KPasswordDialog::getPassword( password, TQString( req + i18n( " password:" ) ) );
 					// 			TQTextStream os( socket );
@@ -251,7 +251,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 					// 			if ( result == KPasswordDialog::Accepted ) {
 					// 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					// 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "password got from user" ), GlobalConfig->debug );
-					// 				pass = TQString( password );
+					// 				pass = password;
 					//
 					// 				pass = pass.remove( '\r' );
 					// 				pass = pass.remove( '\n' );
@@ -331,7 +331,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 					{
 						if ( GlobalConfig->TmpPassword.isEmpty() )
 						{
-							TQCString password;
+							TQString password;
 							TQString pass = "";
 							int result = KPasswordDialog::getPassword( password, TQString( i18n( " password:" ) ) );
 							TQTextStream os( socket );
@@ -340,7 +340,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 							{
 								if ( GlobalConfig->KvpncDebugLevel > 2 )
 									GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "password got from user" ), GlobalConfig->debug );
-								GlobalConfig->TmpPassword = TQString( password );
+								GlobalConfig->TmpPassword = password;
 	
 	
 								// 						if ( GlobalConfig->KvpncDebugLevel > 5 )
