@@ -1471,7 +1471,7 @@ void Utils::readStdOutRetriveIpsecAlgos()
 					TQString Algo = msg.stripWhiteSpace().section(":",1,1).section(",",1,1).section("=",1,1);
 					TQString MinKeySize = msg.stripWhiteSpace().section(":",1,1).section(",",3,3).section("=",1,1);
 					TQString MaxKeySize = msg.stripWhiteSpace().section(":",1,1).section(",",4,4).section("=",1,1);
-					std::cout << "IKE encryption algo found: \"" << Algo << "\", Min: " << MinKeySize << ", Max: " << MaxKeySize << std::endl;
+					std::cout << "IKE encryption algo found: \"" << Algo.local8Bit() << "\", Min: " << MinKeySize.local8Bit() << ", Max: " << MaxKeySize.local8Bit() << std::endl;
 // 					TQStringList AlgoOptList = TQStringList::split("-",AlgoOpt);
 // 					for (TQStringList::Iterator it = AlgoOptList.begin(); it != AlgoOptList.end(); ++it)
 // 					{
@@ -1896,12 +1896,12 @@ int Utils::dottedIpv4Netmask2NetmaskBytes(TQString dottedIpv4Netmask)
 	TQString block2 = dec2bin(part2);
 	TQString block3 = dec2bin(part3);
 	
-	std::cout << "block0: " << block0 << std::endl;
-	std::cout << "block1: " << block1 << std::endl;
-	std::cout << "block2: " << block2 << std::endl;
-	std::cout << "block3: " << block3 << std::endl;
+	std::cout << "block0: " << block0.local8Bit() << std::endl;
+	std::cout << "block1: " << block1.local8Bit() << std::endl;
+	std::cout << "block2: " << block2.local8Bit() << std::endl;
+	std::cout << "block3: " << block3.local8Bit() << std::endl;
 	block = block0 + block1 +block2 + block3;
-	std::cout << "block: " << block.ascii() << std::endl;
+	std::cout << "block: " << block.local8Bit() << std::endl;
 
 	for (int i=0; i< 31;i++)
 	{
@@ -1910,3 +1910,5 @@ int Utils::dottedIpv4Netmask2NetmaskBytes(TQString dottedIpv4Netmask)
 	}
 	return byteSetCount;
 }
+
+#include "utils.moc"
